@@ -23,11 +23,11 @@ App::GitWorkspaceScanner - Scan git repositories in your workspace for local cha
 
 =head1 VERSION
 
-Version 1.0.1
+Version 1.0.2
 
 =cut
 
-our $VERSION = '1.0.1';
+our $VERSION = '1.0.2';
 
 
 =head1 DESCRIPTION
@@ -59,10 +59,11 @@ Print out information about the analysis performed. Off by default.
 =item * C<--workspace>
 
 Root of the workspace to search git repositories into. By default, the search
-is performed on '/'.
+is performed on '/', but you can use any absolute path.
 
 	./scan_git_repositories --workspace=$HOME
 
+
 =item * C<--allow_untracked_files>
 
 Set whether untracked files should generate a warning in the report. Currently
@@ -522,6 +523,15 @@ sub get_unclean_repositories ## no critic (Subroutines::ProhibitExcessComplexity
 }
 
 
+=head1 SEE ALSO
+
+=over 4
+
+=item * L<App::IsGitSynced>
+
+=back
+
+
 =head1 BUGS
 
 Please report any bugs or feature requests through the web interface at
